@@ -265,10 +265,9 @@ class MouseReviewer:
                 # display.
                 braille.displayMessage(obj)
             else:
-                speech.speakUtterances(
-                    self._currentMouseOver.script.speechGenerator.getSpeech(
-                            obj,
-                            False))
+                speech.speak(
+                    self._currentMouseOver.script.speechGenerator.\
+                        generateSpeech(obj))
                 self._currentMouseOver.script.updateBraille(obj)
 
     def _getZOrder(self, frame_name):
